@@ -109,6 +109,50 @@ console = Console()
 # Global mode context (set by --mode flag or auto-detected)
 _current_mode: OperationalMode | None = None
 
+# Global banner flag (set by --no-banner flag)
+_show_banner: bool = True
+
+
+def print_banner() -> None:
+    """Print SpecFact CLI ASCII art banner with smooth gradient effect."""
+    from rich.text import Text
+
+    banner_lines = [
+        "",
+        "  ███████╗██████╗ ███████╗ ██████╗███████╗ █████╗  ██████╗████████╗",
+        "  ██╔════╝██╔══██╗██╔════╝██╔════╝██╔════╝██╔══██╗██╔════╝╚══██╔══╝",
+        "  ███████╗██████╔╝█████╗  ██║     █████╗  ███████║██║        ██║   ",
+        "  ╚════██║██╔═══╝ ██╔══╝  ██║     ██╔══╝  ██╔══██║██║        ██║   ",
+        "  ███████║██║     ███████╗╚██████╗██║     ██║  ██║╚██████╗   ██║   ",
+        "  ╚══════╝╚═╝     ╚══════╝ ╚═════╝╚═╝     ╚═╝  ╚═╝ ╚═════╝   ╚═╝   ",
+        "",
+        "        Spec→Contract→Sentinel for Contract-Driven Development",
+    ]
+
+    # Smooth gradient from bright cyan (top) to blue (bottom) - 6 lines for ASCII art
+    # Using Rich's gradient colors: bright_cyan → cyan → bright_blue → blue
+    gradient_colors = [
+        "black",     # Empty line
+        "blue",      # Line 1 - darkest at top
+        "blue",      # Line 2
+        "cyan",      # Line 3
+        "cyan",      # Line 4
+        "white",     # Line 5
+        "white",     # Line 6 - lightest at bottom
+    ]
+
+    for i, line in enumerate(banner_lines):
+        if line.strip():  # Only apply gradient to non-empty lines
+            if i < len(gradient_colors):
+                # Apply gradient color to ASCII art lines
+                text = Text(line, style=f"bold {gradient_colors[i]}")
+                console.print(text)
+            else:
+                # Tagline in cyan (after empty line)
+                console.print(line, style="cyan")
+        else:
+            console.print()  # Empty line
+
 
 def version_callback(value: bool) -> None:
     """Show version information."""
@@ -156,6 +200,11 @@ def main(
         is_eager=True,
         help="Show version and exit",
     ),
+    no_banner: bool = typer.Option(
+        False,
+        "--no-banner",
+        help="Hide ASCII art banner (useful for CI/CD)",
+    ),
     mode: str | None = typer.Option(
         None,
         "--mode",
@@ -174,6 +223,10 @@ def main(
     - Auto-detect from environment (CoPilot API, IDE integration)
     - Default to CI/CD mode
     """
+    global _show_banner
+    # Set banner flag based on --no-banner option
+    _show_banner = not no_banner
+
     # Show help if no command provided (avoids user confusion)
     if ctx.invoked_subcommand is None:
         # Show help by calling Typer's help callback
@@ -203,7 +256,11 @@ def hello() -> None:
 
 
 # Register command groups
-app.add_typer(constitution.app, name="constitution", help="Manage project constitutions")
+app.add_typer(
+    constitution.app,
+    name="constitution",
+    help="Manage project constitutions (Spec-Kit compatibility layer)",
+)
 app.add_typer(import_cmd.app, name="import", help="Import codebases and Spec-Kit projects")
 app.add_typer(plan.app, name="plan", help="Manage development plans")
 app.add_typer(enforce.app, name="enforce", help="Configure quality gates")
@@ -217,6 +274,13 @@ def cli_main() -> None:
     # Normalize shell names in argv for Typer's built-in completion commands
     normalize_shell_in_argv()
 
+    # Check if --no-banner flag is present (before Typer processes it)
+    no_banner_requested = "--no-banner" in sys.argv
+
+    # Show banner by default unless --no-banner is specified
+    # Banner shows for: no args, --help/-h, or any command (unless --no-banner)
+    show_banner = not no_banner_requested
+
     # Intercept Typer's shell detection for --show-completion and --install-completion
     # when no shell is provided (auto-detection case)
     # On Ubuntu, shellingham detects "sh" (dash) instead of "bash", so we force "bash"
@@ -247,6 +311,12 @@ def cli_main() -> None:
             else:
                 os.environ["_SPECFACT_COMPLETE"] = mapped_shell
 
+    # Show banner by default (unless --no-banner is specified)
+    # Only show once, before Typer processes the command
+    if show_banner:
+        print_banner()
+        console.print()  # Empty line after banner
+
     try:
         app()
     except KeyboardInterrupt:
